@@ -20,4 +20,10 @@ test_that("replacement works", {
   x <- as_index(matrix(1:6, 2))
   split(x, c(1, 1, 2), margin = "time") <- 1:2
   expect_equal(x, as_index(matrix(c(1, 1, 1, 1, 2, 2), 2)))
+  
+  y <- x
+  split(y, factor(c(1, 1, 2), levels = character(0)), margin = "time") <- list()
+  expect_identical(x, y)
+  
+  expect_warning(split(x, 1:3, margin = "time") <- 1:2)
 })
\ No newline at end of file
